"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("source-map-support/register");

var _resolveDebugLevels = _interopRequireDefault(require("resolve-debug-levels"));

var _initAwsClients = _interopRequireDefault(require("./init-aws-clients"));

var _initBroker = _interopRequireDefault(require("./init-broker"));

var _initPerformanceTracer = _interopRequireDefault(require("./init-performance-tracer"));

var _lambdaWorker = _interopRequireDefault(require("./lambda-worker"));

var _wrapTrie = _interopRequireDefault(require("../common/wrap-trie"));

var _initUploader = _interopRequireDefault(require("./init-uploader"));

var _metrics = require("./metrics");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const log = (0, _resolveDebugLevels.default)('resolve:resolve-runtime:cloud-entry');

const index = async ({
  assemblies,
  constants,
  domain
}) => {
  let subSegment = null;
  log.debug(`starting lambda 'cold start'`);

  try {
    log.debug('configuring reSolve framework');
    const resolve = {
      seedClientEnvs: assemblies.seedClientEnvs,
      serverImports: assemblies.serverImports,
      ...domain,
      ...constants,
      routesTrie: (0, _wrapTrie.default)(domain.apiHandlers, constants.rootPath),
      publisher: {},
      assemblies
    };
    log.debug('preparing performance tracer');
    await (0, _initPerformanceTracer.default)(resolve);
    const segment = resolve.performanceTracer.getSegment();
    subSegment = segment.addNewSubsegment('initResolve');
    log.debug('preparing aws clients');
    await (0, _initAwsClients.default)(resolve);
    log.debug('preparing event broker');
    await (0, _initBroker.default)(resolve);
    log.debug('preparing uploader');
    await (0, _initUploader.default)(resolve);

    resolve.sendReactiveEvent = async event => {
      const eventDescriptor = {
        topic: `${process.env.RESOLVE_DEPLOYMENT_ID}/${event.type}/${event.aggregateId}`,
        payload: JSON.stringify(event),
        qos: 1
      };
      await resolve.mqtt.publish(eventDescriptor).promise();
    };

    log.debug(`lambda 'cold start' succeeded`);
    return _lambdaWorker.default.bind(null, resolve);
  } catch (error) {
    log.error(`lambda 'cold start' failure`, error);
    subSegment.addError(error);
    await (0, _metrics.putInternalError)(error);
  } finally {
    if (subSegment != null) {
      subSegment.close();
    }
  }
};

var _default = index;
exports.default = _default;
//# sourceMappingURL=index.js.map