"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _resolveCommand = _interopRequireDefault(require("resolve-command"));

var _resolveQuery = _interopRequireDefault(require("resolve-query"));

var _resolveSaga = _interopRequireDefault(require("resolve-saga"));

var _crypto = _interopRequireDefault(require("crypto"));

var _onCommandExecuted = _interopRequireDefault(require("./on-command-executed"));

var _eventListener = _interopRequireDefault(require("./event-listener"));

var _eventBus = _interopRequireDefault(require("./event-bus"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const DEFAULT_WORKER_LIFETIME = 4 * 60 * 1000;

const initResolve = async resolve => {
  const performanceTracer = resolve.performanceTracer;
  const {
    eventstoreAdapter: createEventstoreAdapter,
    readModelConnectors: readModelConnectorsCreators
  } = resolve.assemblies;
  const {
    invokeEventBusAsync,
    aggregates,
    readModels,
    sagas,
    viewModels,
    uploader,
    scheduler,
    monitoring
  } = resolve;
  const eventstoreAdapter = createEventstoreAdapter();
  const readModelConnectors = {};

  for (const name of Object.keys(readModelConnectorsCreators)) {
    readModelConnectors[name] = readModelConnectorsCreators[name]({
      performanceTracer,
      eventstoreAdapter
    });
  }

  if (resolve.getVacantTimeInMillis == null) {
    const endTime = Date.now() + DEFAULT_WORKER_LIFETIME;

    resolve.getVacantTimeInMillis = () => endTime - Date.now();
  }

  Object.defineProperties(resolve, {
    readModelConnectors: {
      value: readModelConnectors
    },
    eventstoreAdapter: {
      value: eventstoreAdapter
    }
  });
  const getVacantTimeInMillis = resolve.getVacantTimeInMillis;
  const onCommandExecuted = (0, _onCommandExecuted.default)(resolve);
  const performAcknowledge = resolve.publisher.acknowledge.bind(resolve.publisher);
  const executeCommand = (0, _resolveCommand.default)({
    aggregates,
    eventstoreAdapter,
    performanceTracer,
    onCommandExecuted,
    monitoring
  });
  const executeQuery = (0, _resolveQuery.default)({
    invokeEventBusAsync,
    eventstoreAdapter,
    readModelConnectors,
    readModels,
    viewModels,
    performanceTracer,
    getVacantTimeInMillis,
    performAcknowledge,
    monitoring
  });
  const executeSaga = (0, _resolveSaga.default)({
    invokeEventBusAsync,
    executeCommand,
    executeQuery,
    eventstoreAdapter,
    readModelConnectors,
    sagas,
    performanceTracer,
    getVacantTimeInMillis,
    performAcknowledge,
    uploader,
    scheduler,
    monitoring
  });
  const eventBus = (0, _eventBus.default)(resolve);
  const eventListener = (0, _eventListener.default)(resolve);
  const eventStore = new Proxy({}, {
    get(_, key) {
      if (key === 'SaveEvent') {
        return async ({
          event
        }) => await eventstoreAdapter.saveEvent(event);
      } else if (key === 'LoadEvents') {
        return async ({
          scopeName,
          ...filter
        }) => await (scopeName, eventstoreAdapter.loadEvents(filter));
      } else {
        return eventstoreAdapter[key[0].toLowerCase() + key.slice(1)].bind(eventstoreAdapter);
      }
    },

    set() {
      throw new Error(`Event store API is immutable`);
    }

  });
  Object.assign(resolve, {
    executeCommand,
    executeQuery,
    executeSaga
  });
  Object.defineProperties(resolve, {
    eventListener: {
      value: eventListener
    },
    eventBus: {
      value: eventBus
    },
    eventStore: {
      value: eventStore
    }
  });
  process.env.RESOLVE_LOCAL_TRACE_ID = _crypto.default.randomBytes(Math.ceil(32 / 2)).toString('hex').slice(0, 32);
};

var _default = initResolve;
exports.default = _default;
//# sourceMappingURL=init-resolve.js.map