"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _initResolve = _interopRequireDefault(require("../common/init-resolve"));

var _disposeResolve = _interopRequireDefault(require("../common/dispose-resolve"));

var _multiplexAsync = _interopRequireDefault(require("../common/utils/multiplex-async"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const initBroker = async resolve => {
  const {
    assemblies: {
      connectPublisher,
      createAndInitConsumer,
      eventBrokerConfig
    },
    eventListeners
  } = resolve;
  const publisher = await connectPublisher({
    address: eventBrokerConfig.publisherAddress,
    eventListeners
  }); // TODO: improve lifecycle

  const consumer = await createAndInitConsumer({
    address: eventBrokerConfig.consumerAddress,
    baseResolve: resolve,
    initResolve: _initResolve.default,
    disposeResolve: _disposeResolve.default,
    publisher
  });

  const invokeEventBusAsync = _multiplexAsync.default.bind(null, async (eventSubscriber, method, parameters) => {
    const currentResolve = Object.create(resolve);

    try {
      await (0, _initResolve.default)(currentResolve);
      const rawMethod = currentResolve.eventBus[method];

      if (typeof rawMethod !== 'function') {
        throw new TypeError(method);
      }

      const result = await rawMethod.call(currentResolve.eventBus, {
        eventSubscriber,
        ...parameters
      });
      return result;
    } finally {
      await (0, _disposeResolve.default)(currentResolve);
    }
  });

  Object.assign(resolve, {
    invokeEventBusAsync,
    publisher,
    consumer
  });
};

var _default = initBroker;
exports.default = _default;
//# sourceMappingURL=init-broker.js.map