"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _resolveEventstoreBase = require("resolve-eventstore-base");

var _resolveLocalEventBroker = require("resolve-local-event-broker");

var _resolveSaga = require("resolve-saga");

var _invokeFilterErrorTypes = _interopRequireDefault(require("../common/utils/invoke-filter-error-types"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const resetDomainHandler = options => async (req, res) => {
  const {
    eventstoreAdapter,
    eventBus,
    publisher,
    readModels,
    sagas
  } = req.resolve;

  try {
    const {
      dropEventStore,
      dropEventBus,
      dropReadModels,
      dropSagas
    } = options;

    if (dropEventStore) {
      await (0, _invokeFilterErrorTypes.default)(eventstoreAdapter.drop.bind(eventstoreAdapter), [_resolveEventstoreBase.EventstoreResourceNotExistError]);
      await (0, _invokeFilterErrorTypes.default)(eventstoreAdapter.init.bind(eventstoreAdapter), [_resolveEventstoreBase.EventstoreResourceAlreadyExistError]);
    }

    const dropReadModelsSagasErrors = [];

    if (dropReadModels) {
      for (const {
        name
      } of readModels) {
        try {
          await eventBus.reset({
            eventSubscriber: name
          });
        } catch (error) {
          dropReadModelsSagasErrors.push(error);
        }
      }
    }

    if (dropSagas) {
      for (const {
        name
      } of [...(0, _resolveSaga.getSchedulersNamesBySagas)(sagas).map(schedulerName => ({
        name: `${schedulerName}`
      })), ...sagas]) {
        try {
          await eventBus.reset({
            eventSubscriber: name
          });
        } catch (error) {
          dropReadModelsSagasErrors.push(error);
        }
      }
    }

    if (dropEventBus) {
      // eslint-disable-next-line no-console
      console.warn(dropReadModelsSagasErrors.map(error => error.message).join('\n'));
      await (0, _invokeFilterErrorTypes.default)(publisher.drop.bind(publisher), [_resolveLocalEventBroker.PublisherResourceNotExistError]);
      await (0, _invokeFilterErrorTypes.default)(publisher.init.bind(publisher), [_resolveLocalEventBroker.PublisherResourceAlreadyExistError]);
    } else {
      if (dropReadModelsSagasErrors.length) {
        const compositeError = new Error(dropReadModelsSagasErrors.map(error => error.message).join('\n'));
        compositeError.stack = dropReadModelsSagasErrors.map(error => error.stack).join('\n');
        throw compositeError;
      }
    }

    res.end('ok');
  } catch (error) {
    // eslint-disable-next-line no-console
    console.error(error);
    res.status(500);
    res.end(String(error));
  }
};

var _default = resetDomainHandler;
exports.default = _default;
//# sourceMappingURL=reset-domain-handler.js.map